@@ -16,7 +16,7 @@ from .structures import (
     RustContents,
     RustItem,
 )
-from .remote.rustplus_pb2 import *
+from .remote.rustplus_proto import *
 from .remote import HeartBeat
 from ..commands import CommandOptions
 from ..exceptions import *
@@ -37,7 +37,7 @@ class RustSocket(BaseRustSocket):
         ip: str = None,
         port: str = None,
         steam_id: int = None,
-        playerToken: int = None,
+        player_token: int = None,
         command_options: CommandOptions = None,
         raise_ratelimit_exception: bool = True,
         ratelimit_limit: int = 25,
@@ -48,7 +48,7 @@ class RustSocket(BaseRustSocket):
             ip=ip,
             port=port,
             steam_id=steam_id,
-            playerToken=playerToken,
+            player_token=player_token,
             command_options=command_options,
             raise_ratelimit_exception=raise_ratelimit_exception,
             ratelimit_limit=ratelimit_limit,
@@ -380,7 +380,7 @@ class RustSocket(BaseRustSocket):
 
         return RustContents(difference, bool(returned_data.has_protection), items)
 
-    @deprecated("Use RustSocket#get_contents")
+    @deprecated("Use RustSocket.get_contents")
     async def get_tc_storage_contents(
         self, eid: int = None, combine_stacks: bool = False
     ) -> RustContents:
